pub enum StreamAnnotation {
Normal,
NotNull,
Done,
}Expand description
Streaming annotation for field-level emission control.
Controls when a field value should be emitted during streaming parsing.
Examples
use simple_agents_healing::schema::{StreamAnnotation, Field, Schema};
// Emit as soon as available (default)
let normal_field = Field {
name: "name".to_string(),
schema: Schema::String,
required: true,
aliases: vec![],
default: None,
description: None,
stream_annotation: StreamAnnotation::Normal,
};
// Don't emit until non-null
let id_field = Field {
name: "id".to_string(),
schema: Schema::Int,
required: true,
aliases: vec![],
default: None,
description: None,
stream_annotation: StreamAnnotation::NotNull,
};
// Only emit when complete
let status_field = Field {
name: "status".to_string(),
schema: Schema::String,
required: true,
aliases: vec![],
default: None,
description: None,
stream_annotation: StreamAnnotation::Done,
};Variants
Normal
Emit field as soon as it’s available (default)
NotNull
Don’t emit until value is non-null (@@stream.not_null)
Done
Only emit when the entire structure is complete (@@stream.done)